---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
Screenshots and GIFS are much appreciated when reporting visual bugs.

**Desktop (please complete the following information):**
 - OS with version [e.g macOS 10.15.7]
 - Qt Backend [e.g PyQt5, PySide2]
 - Python version
